
# Time Branch

Cria para conta o tempo que se fica numa branch até trocar para outra.

Fazendo com que os registro em aplicações de gerenciamento (Jira, Trello) seja mais precisa.


## Instalação

Como usar:

```bash
python file.py [diretorio com git]
```
Com Windows:
```
file.bat [diretorio com git]
```



